@@ -1,11 +1,19 @@
 from binascii import unhexlify
 from time import time
+
 from django import forms
 from django.forms import ModelForm, Form
 from django.utils.translation import ugettext_lazy as _
+
 from django_otp.forms import OTPAuthenticationFormMixin
 from django_otp.oath import totp
 from django_otp.plugins.otp_totp.models import TOTPDevice
+from two_factor.utils import totp_digits
+
+try:
+    from otp_yubikey.models import RemoteYubikeyDevice, YubikeyDevice
+except ImportError:
+    RemoteYubikeyDevice = YubikeyDevice = None
 
 from .models import (PhoneDevice, get_available_phone_methods,
                      get_available_methods)
@@ -40,7 +48,11 @@ class PhoneNumberForm(ModelForm):
 
 
 class DeviceValidationForm(forms.Form):
-    token = forms.IntegerField(label=_("Token"), min_value=1, max_value=999999)
+    token = forms.IntegerField(label=_("Token"), min_value=1, max_value=int('9' * totp_digits()))
+
+    error_messages = {
+        'invalid_token': _('Entered token is not valid.'),
+    }
 
     def __init__(self, device, **args):
         super(DeviceValidationForm, self).__init__(**args)
@@ -49,15 +61,27 @@ class DeviceValidationForm(forms.Form):
     def clean_token(self):
         token = self.cleaned_data['token']
         if not self.device.verify_token(token):
-            raise forms.ValidationError(_('Entered token is not valid'))
+            raise forms.ValidationError(self.error_messages['invalid_token'])
         return token
 
 
-class TOTPDeviceForm(forms.Form):
-    token = forms.IntegerField(label=_("Token"), min_value=0, max_value=999999)
+class YubiKeyDeviceForm(DeviceValidationForm):
+    token = forms.CharField(label=_("YubiKey"))
 
     error_messages = {
-        'invalid_token': _("Please enter a valid token."),
+        'invalid_token': _("The YubiKey could not be verified."),
+    }
+
+    def clean_token(self):
+        self.device.public_id = self.cleaned_data['token'][:-32]
+        return super(YubiKeyDeviceForm, self).clean_token()
+
+
+class TOTPDeviceForm(forms.Form):
+    token = forms.IntegerField(label=_("Token"), min_value=0, max_value=int('9' * totp_digits()))
+
+    error_messages = {
+        'invalid_token': _('Entered token is not valid.'),
     }
 
     def __init__(self, key, user, metadata=None, **kwargs):
@@ -67,7 +91,7 @@ class TOTPDeviceForm(forms.Form):
         self.t0 = 0
         self.step = 30
         self.drift = 0
-        self.digits = 6
+        self.digits = totp_digits()
         self.user = user
         self.metadata = metadata or {}
 
@@ -92,13 +116,14 @@ class TOTPDeviceForm(forms.Form):
                     self.metadata['valid_t0'] = int(time()) - t0
                     validated = True
         if not validated:
-            raise forms.ValidationError({'token': [self.error_messages['invalid_token']]})
+            raise forms.ValidationError(self.error_messages['invalid_token'])
         return token
 
     def save(self):
         return TOTPDevice.objects.create(user=self.user, key=self.key,
                                          tolerance=self.tolerance, t0=self.t0,
                                          step=self.step, drift=self.drift,
+                                         digits=self.digits,
                                          name='default')
 
 
@@ -107,12 +132,26 @@ class DisableForm(forms.Form):
 
 
 class AuthenticationTokenForm(OTPAuthenticationFormMixin, Form):
-    otp_token = forms.IntegerField(label=_("Token"), min_value=1, max_value=999999)
+    otp_token = forms.IntegerField(label=_("Token"), min_value=1,
+                                   max_value=int('9' * totp_digits()))
 
-    def __init__(self, user, **kwargs):
+    def __init__(self, user, initial_device, **kwargs):
+        """
+        `initial_device` is either the user's default device, or the backup
+        device when the user chooses to enter a backup token. The token will
+        be verified against all devices, it is not limited to the given
+        device.
+        """
         super(AuthenticationTokenForm, self).__init__(**kwargs)
         self.user = user
 
+        # YubiKey generates a OTP of 44 characters (not digits). So if the
+        # user's primary device is a YubiKey, replace the otp_token
+        # IntegerField with a CharField.
+        if RemoteYubikeyDevice and YubikeyDevice and \
+                isinstance(initial_device, (RemoteYubikeyDevice, YubikeyDevice)):
+            self.fields['otp_token'] = forms.CharField(label=_('YubiKey'))
+
     def clean(self):
         self.clean_otp(self.user)
         return self.cleaned_data
