@@ -1,4 +1,4 @@
 from .core import (LoginView, SetupView, BackupTokensView, PhoneSetupView,
-                   PhoneDeleteView, SetupCompleteView)
+                   PhoneDeleteView, SetupCompleteView, QRGeneratorView)
 from .mixins import OTPRequiredMixin
 from .profile import ProfileView, DisableView
